﻿* Encoding: UTF-8.
/******************************************************************************
/*
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*        PLAN NACIONAL PARA LA EVALUACIÓN DE LOS APRENDIZAJES (PLANEA)
/*                    TERCER GRADO DE PREESCOLAR (PLANEA 00)
/*
/*                       ****LENGUAJE Y COMUNICACIÓN****
/*
/*                     Ciclo escolar evaluado: 2017 - 2018
/*_____________________________________________________________________________
/*
/*
/*      SINTAXIS PARA ETIQUETAR LA BASE DE DATOS DE ALUMNOS DE LENGUAJE Y
/*                         COMUNICACIÓN EN FORMATO SPSS
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla PLANEA00_2018_Alumnos_LyC.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel. 54820900  Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. México. D.F.
/*
/* FECHA DE LIBERACIÓN:  05 DE JULIO 2019
/*
/*  ****************************************************************************/




/***********************************************************************
/*                  Código para etiquetar las variables
/*
/**********************************************************************.
VARIABLE LABELS
       NACIONAL       "Variable auxiliar para obtener promedios nacionales"
       ALUMNO         "Identificador del alumno"
       ESCUELA        "Identificador de la escuela"
       ID_SERV        "Tipo de escuela (identificador numérico)"
       SERV           "Tipo de escuela"
       ESTRATO        "Estrato del diseño muestral"
       RURALIDAD      "Rural-Urbano"
       ID_LYC_INSTR   "Identificador del cuadernillo de examen de lenguaje y comunicación"
       SEXO           "Sexo del alumno"
       EDAD_AC        "Edad en años cumplidos estimada a partir del campo EDAD"
       MES_NAC        "Mes de nacimiento del alumno"
       EDAD           "Edad del alumno, al último día de la aplicación de la prueba, estimada a partir del día, mes y año de nacimiento"
       EDAD_ACC       "Edad en años cumplidos por categoría estimada a partir del campo EDAD"
       EDAD_AT        "Edad arriba de la típica estimada a partir del campo EDAD"
       W_FSTUWT       "Peso muestral o ponderador del alumno"
       DOCENTE        "Identificador del docente"
       KLA_1          "Escribir de izquierda a derecha una palabra o frase con la intención de representar una preferencia."
       KLA_2          "Escribir una palabra o frase con la intención de representar una preferencia."
       KLA_3          "Escribir su nombre."
       KLA_4          "Describir personas, personajes, objetos o lugares."
       KLA_5          "Enunciar la secuencia de un procedimiento."
       KLA_6          "Emplear marcadores temporales para enunciar la secuencia de un procedimiento."
       KLA_7          "Diferenciar entre textos de cuento y estudio a partir de sus características gráficas y del lenguaje que se usa en cada uno."
       KLA_8          "Identificar el título de un libro."
       KLA_9          "Identificar el autor de un libro."
       KLA_10         "Identificar que se lee en el texto escrito."
       KLA_11         "Identificar que leer y escribir se hace de izquierda a derecha."
       KLA_12         "Identificar que leer y escribir se hace de arriba abajo."
       KLA_13         "Expresar el contenido de un texto (cuento o fábula) que se lee."
       KLB_1          "Identificar el uso del calendario."
       KLB_2          "Reconocer  los nombres de los días de la semana en un calendario."
       KLB_3          "Identificar un acontecimiento en el calendario"
       KLB_4          "Interpretar el día de la semana en que se celebra un acontecimiento"
       KLB_5          "Distinguir la escritura convencional de los números de los días de la semana."
       KLB_6          "Dar información acerca del valor sonoro de algunas letras."
       KLB_7          "Dar información acerca del nombre y orden de algunas letras."
       KLB_8          "Establecer comparaciones entre características gráficas de las palabras."
       KLB_9          "Reconocer características de las palabras y las letras."
       KLB_10         "Identificar las palabras que se escriben de la misma forma en una rima."
       KLB_11         "Narrar un cuento siguiendo la secuencia de sucesos."
       KLB_12         "Utilizar recursos literarios en una narración."
       KLB_13         "Narrar alguna experiencia real o imaginaria empleando referencias espaciales y temporales (aquí, allá, cerca de, hoy, ayer, esta semana, antes,  primero, después, tarde, más tarde)."
       KLC_1          "Anticipar el contenido de un texto a partir de la lectura del título y la exploración del libro."
       KLC_2          "Anticipar el contenido de un cuento a partir de la lectura de un fragmento."
       KLC_3          "Mencionar el pasaje de una narración oral que genera una reacción o interés."
       KLC_4          "Explicar, a partir de una narración, por qué un hecho es fantástico o real."
       KLC_5          "Identificar un error de cantidad mínima en la escritura de una palabra."
       KLC_6          "Reconocer una palabra bien escrita."
       KLC_7          "Identificar uno o más errores de correspondencia grafofonética en la escritura de una palabra."
       KLC_8          "Reconocer un error de variabilidad interna en la escritura de una palabra."
       KLC_9          "Reconocer la escritura de una palabra con apoyo del contexto."
       KLC_10         "Exponer información sobre un tópico."
       KLC_11         "Reconocer su nombre escrito."
       KLD_1          "Establecer similitudes sonoro-gráficas entre su nombre y otras palabras."
       KLD_2          "Escribir de izquierda a derecha una palabra a partir del nombre propio."
       KLD_3          "Escribir una palabra a partir del nombre propio."
       KLD_4          "Expresar su nombre completo."
       KLD_5          "Expresar información de las personas con quienes vive."
       KLD_6          "Proporcionar su dirección o referentes espaciales acerca del lugar donde vive."
       KLD_7          "Expresar características del lugar donde vive."
       KLD_8          "Compartir información con base en una situación problemática."
       KLD_9          "Compartir gustos y preferencias."
       KLD_10         "Reconocer el contenido de un texto literario (cuento)."
       KLD_11         "Reconocer el contenido de un texto informativo (libro temático de animales, plantas, espacio)."
       KLD_12         "Reconocer el contenido de un instructivo."
       KLD_13         "Identificar la función de las imágenes en un texto."
       PV1LYC         "Primer valor plausible de Lenguaje y Comunicación"
       PV2LYC         "Segundo valor plausible de Lenguaje y Comunicación"
       PV3LYC         "Tercer valor plausible de Lenguaje y Comunicación"
       PV4LYC         "Cuarto valor plausible de Lenguaje y Comunicación"
       PV5LYC         "Quinto valor plausible de Lenguaje y Comunicación"
       PV6LYC         "Sexto valor plausible de Lenguaje y Comunicación"
       PV7LYC         "Septimo valor plausible de Lenguaje y Comunicación"
       PV8LYC         "Octavo valor plausible de Lenguaje y Comunicación"
       PV9LYC         "Noveno valor plausible de Lenguaje y Comunicación"
       PV10LYC        "Décimo valor plausible de Lenguaje y Comunicación"
       PV11LYC        "Decimoprimero valor plausible de Lenguaje y Comunicación"
       PV12LYC        "Decimosegundo valor plausible de Lenguaje y Comunicación"
       PV13LYC        "Decimotercero valor plausible de Lenguaje y Comunicación"
       PV14LYC        "Decimocuarto valor plausible de Lenguaje y Comunicación"
       PV15LYC        "Decimoquinto valor plausible de Lenguaje y Comunicación"
       PV16LYC        "Decimosexto valor plausible de Lenguaje y Comunicación"
       PV17LYC        "Decimoseptimo valor plausible de Lenguaje y Comunicación"
       PV18LYC        "Decimooctavo valor plausible de Lenguaje y Comunicación"
       PV19LYC        "Decimonoveno valor plausible de Lenguaje y Comunicación"
       PV20LYC        "Vigésimo valor plausible de Lenguaje y Comunicación"
       LYCNVL1        "Niveles de logro del Primer valor plausible de Lenguaje y Comunicación"
       LYCNVL2        "Niveles de logro del Segundo valor plausible de Lenguaje y Comunicación"
       LYCNVL3        "Niveles de logro del Tercer valor plausible de Lenguaje y Comunicación"
       LYCNVL4        "Niveles de logro del Cuart valor plausible de Lenguaje y Comunicación"
       LYCNVL5        "Niveles de logro del Quinto valor plausible de Lenguaje y Comunicación"
       LYCNVL6        "Niveles de logro del Sexto valor plausible de Lenguaje y Comunicación"
       LYCNVL7        "Niveles de logro del Séptimo valor plausible de Lenguaje y Comunicación"
       LYCNVL8        "Niveles de logro del Octavo valor plausible de Lenguaje y Comunicación"
       LYCNVL9        "Niveles de logro del Noveno valor plausible de Lenguaje y Comunicación"
       LYCNVL10       "Niveles de logro del Décimo valor plausible de Lenguaje y Comunicación"
       LYCNVL11       "Niveles de logro del Decimoprimerovalor plausible de Lenguaje y Comunicación"
       LYCNVL12       "Niveles de logro del Decimosegundo valor plausible de Lenguaje y Comunicación"
       LYCNVL13       "Niveles de logro del Decimotercero valor plausible de Lenguaje y Comunicación"
       LYCNVL14       "Niveles de logro del Decimocuarto valor plausible de Lenguaje y Comunicación"
       LYCNVL15       "Niveles de logro del Decimoquinto valor plausible de Lenguaje y Comunicación"
       LYCNVL16       "Niveles de logro del Decimosexto valor plausible de Lenguaje y Comunicación"
       LYCNVL17       "Niveles de logro del Decimoseptimo valor plausible de Lenguaje y Comunicación"
       LYCNVL18       "Niveles de logro del Decimooctavo valor plausible de Lenguaje y Comunicación"
       LYCNVL19       "Niveles de logro del Decimonoveno valor plausible de Lenguaje y Comunicación"
       LYCNVL20       "Niveles de logro del Vigésimo valor plausible de Lenguaje y Comunicación"
       LYCNVLII1      "Alumnos que alcanzan al menos el nivel II de logro del Primer valor plausible de Lenguaje y Comunicación"
       LYCNVLII2      "Alumnos que alcanzan al menos el nivel II de logro del Segundo valor plausible de Lenguaje y Comunicación"
       LYCNVLII3      "Alumnos que alcanzan al menos el nivel II de logro del Tercer valor plausible de Lenguaje y Comunicación"
       LYCNVLII4      "Alumnos que alcanzan al menos el nivel II de logro del Cuart valor plausible de Lenguaje y Comunicación"
       LYCNVLII5      "Alumnos que alcanzan al menos el nivel II de logro del Quinto valor plausible de Lenguaje y Comunicación"
       LYCNVLII6      "Alumnos que alcanzan al menos el nivel II de logro del Sexto valor plausible de Lenguaje y Comunicación"
       LYCNVLII7      "Alumnos que alcanzan al menos el nivel II de logro del Séptimo valor plausible de Lenguaje y Comunicación"
       LYCNVLII8      "Alumnos que alcanzan al menos el nivel II de logro del Octavo valor plausible de Lenguaje y Comunicación"
       LYCNVLII9      "Alumnos que alcanzan al menos el nivel II de logro del Noveno valor plausible de Lenguaje y Comunicación"
       LYCNVLII10     "Alumnos que alcanzan al menos el nivel II de logro del Décimo valor plausible de Lenguaje y Comunicación"
       LYCNVLII11     "Alumnos que alcanzan al menos el nivel II de logro del Decimoprimerovalor plausible de Lenguaje y Comunicación"
       LYCNVLII12     "Alumnos que alcanzan al menos el nivel II de logro del Decimosegundo valor plausible de Lenguaje y Comunicación"
       LYCNVLII13     "Alumnos que alcanzan al menos el nivel II de logro del Decimotercero valor plausible de Lenguaje y Comunicación"
       LYCNVLII14     "Alumnos que alcanzan al menos el nivel II de logro del Decimocuarto valor plausible de Lenguaje y Comunicación"
       LYCNVLII15     "Alumnos que alcanzan al menos el nivel II de logro del Decimoquinto valor plausible de Lenguaje y Comunicación"
       LYCNVLII16     "Alumnos que alcanzan al menos el nivel II de logro del Decimosexto valor plausible de Lenguaje y Comunicación"
       LYCNVLII17     "Alumnos que alcanzan al menos el nivel II de logro del Decimoseptimo valor plausible de Lenguaje y Comunicación"
       LYCNVLII18     "Alumnos que alcanzan al menos el nivel II de logro del Decimooctavo valor plausible de Lenguaje y Comunicación"
       LYCNVLII19     "Alumnos que alcanzan al menos el nivel II de logro del Decimonoveno valor plausible de Lenguaje y Comunicación"
       LYCNVLII20     "Alumnos que alcanzan al menos el nivel II de logro del Vigésimo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII1     "Alumnos que alcanzan al menos el nivel III de logro del Primer valor plausible de Lenguaje y Comunicación"
       LYCNVLIII2     "Alumnos que alcanzan al menos el nivel III de logro del Segundo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII3     "Alumnos que alcanzan al menos el nivel III de logro del Tercer valor plausible de Lenguaje y Comunicación"
       LYCNVLIII4     "Alumnos que alcanzan al menos el nivel III de logro del Cuart valor plausible de Lenguaje y Comunicación"
       LYCNVLIII5     "Alumnos que alcanzan al menos el nivel III de logro del Quinto valor plausible de Lenguaje y Comunicación"
       LYCNVLIII6     "Alumnos que alcanzan al menos el nivel III de logro del Sexto valor plausible de Lenguaje y Comunicación"
       LYCNVLIII7     "Alumnos que alcanzan al menos el nivel III de logro del Séptimo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII8     "Alumnos que alcanzan al menos el nivel III de logro del Octavo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII9     "Alumnos que alcanzan al menos el nivel III de logro del Noveno valor plausible de Lenguaje y Comunicación"
       LYCNVLIII10    "Alumnos que alcanzan al menos el nivel III de logro del Décimo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII11    "Alumnos que alcanzan al menos el nivel III de logro del Decimoprimerovalor plausible de Lenguaje y Comunicación"
       LYCNVLIII12    "Alumnos que alcanzan al menos el nivel III de logro del Decimosegundo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII13    "Alumnos que alcanzan al menos el nivel III de logro del Decimotercero valor plausible de Lenguaje y Comunicación"
       LYCNVLIII14    "Alumnos que alcanzan al menos el nivel III de logro del Decimocuarto valor plausible de Lenguaje y Comunicación"
       LYCNVLIII15    "Alumnos que alcanzan al menos el nivel III de logro del Decimoquinto valor plausible de Lenguaje y Comunicación"
       LYCNVLIII16    "Alumnos que alcanzan al menos el nivel III de logro del Decimosexto valor plausible de Lenguaje y Comunicación"
       LYCNVLIII17    "Alumnos que alcanzan al menos el nivel III de logro del Decimoseptimo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII18    "Alumnos que alcanzan al menos el nivel III de logro del Decimooctavo valor plausible de Lenguaje y Comunicación"
       LYCNVLIII19    "Alumnos que alcanzan al menos el nivel III de logro del Decimonoveno valor plausible de Lenguaje y Comunicación"
       LYCNVLIII20    "Alumnos que alcanzan al menos el nivel III de logro del Vigésimo valor plausible de Lenguaje y Comunicación"
       WVARSTRR       "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
       W_FSTR1        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR2        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR3        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR4        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR5        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR6        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR7        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR8        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR9        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR10       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR11       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR12       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR13       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR14       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR15       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR16       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR17       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR18       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR19       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR20       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR21       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR22       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR23       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR24       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR25       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR26       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR27       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR28       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR29       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR30       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR31       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR32       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR33       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR34       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR35       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR36       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR37       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR38       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR39       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR40       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR41       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR42       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR43       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR44       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR45       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR46       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR47       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR48       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR49       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR50       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR51       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR52       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR53       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR54       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR55       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR56       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR57       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR58       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR59       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR60       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR61       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR62       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR63       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR64       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR65       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR66       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR67       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR68       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR69       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR70       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR71       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR72       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR73       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR74       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR75       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR76       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR77       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR78       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR79       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR80       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR81       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR82       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR83       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR84       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR85       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR86       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR87       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR88       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR89       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR90       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR91       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR92       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR93       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR94       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR95       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR96       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR97       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR98       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR99       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR100      "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       VERSION        "Versión de la base de datos"
.





/***********************************************************************
/* Etiquetas de valores.
/*
/**********************************************************************.

VALUE LABELS
       ID_SERV
                     1      "General Pública"
                     2      "Indígena"
                     3      "Técnica Pública"
                     4      "Telesecundaria"
                     5      "Comunitaria"
                     6      "Privada"/
       RURALIDAD
                     0      "Urbano"
                     1      "Rural"
                     9      "No identificada"/
       SEXO
                     1      "Hombre"
                     2      "Mujer"
                     8      "Respuesta múltiple"
                     9      "Respuesta omitida"/
       EDAD_AC
                     4      "4 años"
                     5      "5 años"
                     6      "6 años"
                     7      "7 años"
                     98     "Respuesta múltiple"
                     99     "Respuesta omitida"/
       MES_NAC
                     1      "Enero"
                     2      "Febrero"
                     3      "Marzo"
                     4      "Abril"
                     5      "Mayo"
                     6      "Junio"
                     7      "Julio"
                     8      "Agosto"
                     9      "Septiembre"
                     10     "Octubre"
                     11     "Noviembre"
                     12     "Diciembre"
                     98    "Respuesta múltiple"
                     99    "Respuesta omitida"/
       EDAD
                     99     "Respuesta omitida"/
       EDAD_ACC
                     1      "5 años o menos"
                     2      "6 años o más"
                     99     "Respuesta omitida"/
       EDAD_AT
                     1      "Edad arriba de la típica"
                     2      "Edad típica"
                     99     "Respuesta omitida"/
       DOCENTE
                     9999   "El docente no respondió el cuadernillo"/
       KLA_1
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLA_2
       KLA_3
       KLA_4
       KLA_5
       KLA_6
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLA_7
       KLA_8
       KLA_9
       KLA_10
       KLA_11
       KLA_12
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLA_13
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLB_1
       KLB_2
       KLB_3
       KLB_4
       KLB_5
       KLB_6
       KLB_7
       KLB_8
       KLB_9
       KLB_10
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLB_11
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLB_12
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLB_13
       KLC_1
       KLC_2
       KLC_3
       KLC_4
       KLC_5
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLC_6
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLC_7
       KLC_8
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLC_9
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLC_10
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLC_11
       KLD_1
       KLD_2
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLD_3
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLD_4
       KLD_5
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLD_6
       KLD_7
       KLD_8
       KLD_9
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KLD_10
       KLD_11
       KLD_12
       KLD_13
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       LYCNVL1
       LYCNVL2
       LYCNVL3
       LYCNVL4
       LYCNVL5
       LYCNVL6
       LYCNVL7
       LYCNVL8
       LYCNVL9
       LYCNVL10
       LYCNVL11
       LYCNVL12
       LYCNVL13
       LYCNVL14
       LYCNVL15
       LYCNVL16
       LYCNVL17
       LYCNVL18
       LYCNVL19
       LYCNVL20
                     1      "Nivel I"
                     2      "Nivel II"
                     3      "Nivel III"
                     4      "Nivel IV"/
       LYCNVLII1
       LYCNVLII2
       LYCNVLII3
       LYCNVLII4
       LYCNVLII5
       LYCNVLII6
       LYCNVLII7
       LYCNVLII8
       LYCNVLII9
       LYCNVLII10
       LYCNVLII11
       LYCNVLII12
       LYCNVLII13
       LYCNVLII14
       LYCNVLII15
       LYCNVLII16
       LYCNVLII17
       LYCNVLII18
       LYCNVLII19
       LYCNVLII20
                     0      "Nivel I"
                     1      "Al menos el nivel II"/
       LYCNVLIII1
       LYCNVLIII2
       LYCNVLIII3
       LYCNVLIII4
       LYCNVLIII5
       LYCNVLIII6
       LYCNVLIII7
       LYCNVLIII8
       LYCNVLIII9
       LYCNVLIII10
       LYCNVLIII11
       LYCNVLIII12
       LYCNVLIII13
       LYCNVLIII14
       LYCNVLIII15
       LYCNVLIII16
       LYCNVLIII17
       LYCNVLIII18
       LYCNVLIII19
       LYCNVLIII20
                     0      "Nivel I y II"
                     1      "Al menos el nivel III"
.
EXECUTE.



/***********************************************************************
/* Valores perdidos.
/*
/**********************************************************************.

MISSING VALUES RURALIDAD (9).
MISSING VALUES SEXO      (8,9).
MISSING VALUES EDAD_AC   (98,99).
MISSING VALUES MES_NAC   (98,99).
MISSING VALUES EDAD      (99).
MISSING VALUES EDAD_ACC  (99).
MISSING VALUES EDAD_AT   (99).
MISSING VALUES DOCENTE   (9999).
MISSING VALUES KLA_1 TO KLD_13 (94 TO 99).
EXECUTE.
